[−][src]Struct npm_package_json::Package
The top-level package.json structure.
Fields
name: StringThe package name.
version: StringThe package version.
description: Option<String>The optional package description.
keywords: Vec<String>The optional list of keywords.
homepage: Option<String>The optional package homepage.
bugs: Option<Bug>The optional bug contact form.
license: Option<String>The optional package license.
The optional author.
contributors: Vec<PersonReference>The optional list of contributors.
files: Vec<String>The optional list of files to include. Each entry defines a regex pattern.
main: Option<String>The optional package main entry file.
browser: Option<String>The optional package browser entry file.
This is usually defined in libraries that are meant to be consumed by
browsers. These Thoes can refer to objects that are not available inside
a nodejs environment (like window).
bin: BinSetThe optional set of binary definitions.
man: Option<ManReference>The optional list of man page references.
repository: Option<RepositoryReference>The optional repository reference.
scripts: ScriptsSetThe optional list of script entries.
dependencies: DepsSetThe optional list of dependencies.
dev_dependencies: DepsSetThe optional list of development dependencies.
peer_dependencies: DepsSetThe optional list of peer dependencies.
bundled_dependencies: DepsSetThe optional list of bundled dependencies.
optional_dependencies: DepsSetThe optional list of optional dependencies.
engines: EnginesSetThe optional list of engine entries.
private: boolThe package privacy.
others: BTreeMap<String, Value>Other custom fields that have been defined inside the package.json
file.
Implementations
impl Package[src]
pub fn from_path(path: impl AsRef<Path>) -> Result<Self>[src]
Deserializes a Package from a file path.
pub fn from_reader<R: Read>(r: R) -> Result<Self>[src]
Deserializes a Package from an IO stream.
pub fn from_slice(v: &[u8]) -> Result<Self>[src]
Deserializes a Package from bytes.